@@ -308,6 +308,7 @@ DEFAULTS = [
             ('pylint',
              {
               'enable': True,
+              'max_entries': 30,
               }),
             ('workingdir',
              {
@@ -611,6 +612,10 @@ NAME_MAP = {
             'startup/fixed_directory',
           ]
          ),
+        ('pylint', [
+          'history_filenames',
+          ]
+         ),
     ]
 }
 
@@ -625,4 +630,4 @@ NAME_MAP = {
 #    or if you want to *rename* options, then you need to do a MAJOR update in
 #    version, e.g. from 3.0.0 to 4.0.0
 # 3. You don't need to touch this value if you're just adding a new option
-CONF_VERSION = '57.3.0'
+CONF_VERSION = '57.4.0'
